==> webkit2gtk_2.44.0.orig.tar.xz: webkitgtk-2.44.0/Source/WebCore/Modules/webtransport/WebTransportBidirectionalStreamConstructionParameters.cpp <==
/*
 * Copyright (C) 2023 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "WebTransportBidirectionalStreamConstructionParameters.h"

#include "ReadableStreamSource.h"
#include "WritableStreamSink.h"

namespace WebCore {

WebTransportBidirectionalStreamConstructionParameters::WebTransportBidirectionalStreamConstructionParameters(Ref<ReadableStreamSource>&& source, Ref<WritableStreamSink>&& sink)
    : source(WTFMove(source))
    , sink(WTFMove(sink)) { }

WebTransportBidirectionalStreamConstructionParameters::WebTransportBidirectionalStreamConstructionParameters(WebTransportBidirectionalStreamConstructionParameters&&) = default;

WebTransportBidirectionalStreamConstructionParameters& WebTransportBidirectionalStreamConstructionParameters::operator=(WebTransportBidirectionalStreamConstructionParameters&&) = default;

WebTransportBidirectionalStreamConstructionParameters::~WebTransportBidirectionalStreamConstructionParameters() = default;

}

==> webkit2gtk_2.50.4.orig.tar.xz: webkitgtk-2.50.4/Source/WebCore/Modules/webtransport/WebTransportBidirectionalStreamConstructionParameters.cpp <==
/*
 * Copyright (C) 2023 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "WebTransportBidirectionalStreamConstructionParameters.h"

#include "WritableStreamSink.h"

namespace WebCore {

WebTransportBidirectionalStreamConstructionParameters::WebTransportBidirectionalStreamConstructionParameters(WebTransportStreamIdentifier identifier, Ref<WritableStreamSink>&& sink)
    : identifier(identifier)
    , sink(WTFMove(sink)) { }

WebTransportBidirectionalStreamConstructionParameters::WebTransportBidirectionalStreamConstructionParameters(WebTransportBidirectionalStreamConstructionParameters&&) = default;

WebTransportBidirectionalStreamConstructionParameters& WebTransportBidirectionalStreamConstructionParameters::operator=(WebTransportBidirectionalStreamConstructionParameters&&) = default;

WebTransportBidirectionalStreamConstructionParameters::~WebTransportBidirectionalStreamConstructionParameters() = default;

WebTransportBidirectionalStreamConstructionParameters WebTransportBidirectionalStreamConstructionParameters::isolatedCopy() &&
{
    return { identifier, Ref { sink } };
}

}
